HandleDecoder

Trait HandleDecoder 

pub trait HandleDecoder: InternalHandleDecoder {
    // Required methods
    fn take_raw_handle(&mut self) -> Result<u32, DecodeError>;
    fn handles_remaining(&mut self) -> usize;
}
A decoder which support Zircon handles.

Required Methods

fn take_raw_handle(&mut self) -> Result<u32, DecodeError>

Takes the next raw handle from the decoder.

The returned raw handle must not be considered owned until the decoder is committed.

fn handles_remaining(&mut self) -> usize

Returns the number of handles remaining in the decoder.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors