Instant

Struct Instant 

pub struct Instant<T, U = NsUnit>(/* private fields */);
A timestamp from the kernel. Generic over both the timeline and the units it is measured in.

Implementations



impl Instant<MonotonicTimeline>

pub fn get() -> Instant<MonotonicTimeline>

Get the current monotonic time which does not advance during system suspend.

Wraps the zx_clock_get_monotonic syscall.

pub fn after( duration: Duration<MonotonicTimeline>, ) -> Instant<MonotonicTimeline>

Compute a deadline for the time in the future that is the given Duration away.

Wraps the zx_deadline_after syscall.

pub fn sleep(self)

Sleep until the given time.

Wraps the zx_nanosleep syscall.



impl Instant<BootTimeline>

pub fn get() -> Instant<BootTimeline>

Get the current boot time which advances during system suspend.

pub fn after(duration: Duration<BootTimeline>) -> Instant<BootTimeline>

Compute a deadline for the time in the future that is the given Duration away.



impl<T, U> Instant<T, U>
where T: Timeline, U: TimeUnit,

pub const ZERO: Instant<T, U>



impl<T> Instant<T>
where T: Timeline,

pub const INFINITE: Instant<T>

pub const INFINITE_PAST: Instant<T>

pub const fn into_nanos(self) -> i64

Returns the number of nanoseconds since the epoch contained by this Time.

pub const fn from_nanos(nanos: i64) -> Instant<T>

Return a strongly-typed Time from a raw number of nanoseconds.



impl Instant<MonotonicTimeline, TicksUnit>

pub fn get() -> Instant<MonotonicTimeline, TicksUnit>

Read the number of high-precision timer ticks on the monotonic timeline. These ticks may be processor cycles, high speed timer, profiling timer, etc. They do not advance while the system is suspended.

Wraps the zx_ticks_get syscall.



impl Instant<BootTimeline, TicksUnit>

pub fn get() -> Instant<BootTimeline, TicksUnit>

Read the number of high-precision timer ticks on the boot timeline. These ticks may be processor cycles, high speed timer, profiling timer, etc. They advance while the system is suspended.



impl<T> Instant<T, TicksUnit>
where T: Timeline,

pub const fn into_raw(self) -> i64

Return the number of ticks contained by this Ticks.

pub const fn from_raw(raw: i64) -> Instant<T, TicksUnit>

Return a strongly-typed Ticks from a raw number of system ticks.

pub fn per_second() -> i64

Return the number of high-precision timer ticks in a second.

Wraps the zx_ticks_per_second syscall.