Msi

Struct Msi 

pub struct Msi(/* private fields */);
An object representing a Zircon Message Signaled Interrupt (MSI).

As essentially a subtype of NullableHandle, it can be freely interconverted.

Implementations



impl Msi

pub fn raw_handle(&self) -> u32

Return the handle’s integer value.

pub fn invalid() -> Msi

pub fn is_invalid(&self) -> bool

pub fn into_raw(self) -> u32

Return the raw handle’s integer value without closing it when self is dropped.

pub fn unowned(&self) -> Unowned<'_, Msi>

Returns an [Unowned] referring to this handle.

pub fn as_handle_ref(&self) -> Unowned<'_, NullableHandle>

Returns a [HandleRef] referring to this handle.

pub fn duplicate_handle(&self, rights: Rights) -> Result<Msi, Status>

Wraps the zx_handle_duplicate syscall.

pub fn replace_handle(self, rights: Rights) -> Result<Msi, Status>

Wraps the zx_handle_replace syscall.

pub fn into_handle(self) -> NullableHandle

Converts the value into its inner handle.

pub fn signal( &self, clear_mask: Signals, set_mask: Signals, ) -> Result<(), Status>

Wraps the zx_object_signal syscall.

pub fn wait_one( &self, signals: Signals, deadline: Instant<MonotonicTimeline>, ) -> WaitResult

Wraps the zx_object_wait_one syscall.

pub fn wait_async( &self, port: &Port, key: u64, signals: Signals, options: WaitAsyncOpts, ) -> Result<(), Status>

Wraps the zx_object_wait_async syscall.

pub fn wait_item(&self, signals: Signals) -> WaitItem<'_>

Return a WaitItem for this handle and the provided signals to use with object_wait_many.

pub fn get_name(&self) -> Result<Name, Status>

Wraps a call to the zx_object_get_property syscall for the ZX_PROP_NAME property.

pub fn set_name(&self, name: &Name) -> Result<(), Status>

Wraps a call to the zx_object_set_property syscall for the ZX_PROP_NAME property.

pub fn basic_info(&self) -> Result<HandleBasicInfo, Status>

Wraps the zx_object_get_info syscall for the ZX_INFO_HANDLE_BASIC topic.

pub fn count_info(&self) -> Result<HandleCountInfo, Status>

Wraps the zx_object_get_info syscall for the ZX_INFO_HANDLE_COUNT topic.

pub fn koid(&self) -> Result<Koid, Status>

Returns the [Koid] for the object referred to by this handle.