Struct Rights
pub struct Rights(/* private fields */);Expand description
Rights associated with a handle.
See rights for more information.
Implementations
impl Rights
impl Rights
pub const NONE: Rights
pub const DUPLICATE: Rights
pub const TRANSFER: Rights
pub const READ: Rights
pub const WRITE: Rights
pub const EXECUTE: Rights
pub const MAP: Rights
pub const GET_PROPERTY: Rights
pub const SET_PROPERTY: Rights
pub const ENUMERATE: Rights
pub const DESTROY: Rights
pub const SET_POLICY: Rights
pub const GET_POLICY: Rights
pub const SIGNAL: Rights
pub const SIGNAL_PEER: Rights
pub const WAIT: Rights
pub const INSPECT: Rights
pub const MANAGE_JOB: Rights
pub const MANAGE_PROCESS: Rights
pub const MANAGE_THREAD: Rights
pub const APPLY_PROFILE: Rights
pub const MANAGE_SOCKET: Rights
pub const OP_CHILDREN: Rights
pub const RESIZE: Rights
pub const ATTACH_VMO: Rights
pub const MANAGE_VMO: Rights
pub const SAME_RIGHTS: Rights
pub const BASIC: Rights
pub const IO: Rights
pub const PROPERTY: Rights
pub const POLICY: Rights
pub const RESOURCE_BASIC: Rights
pub const CHANNEL_DEFAULT: Rights
pub const VMO_DEFAULT: Rights
impl Rights
impl Rights
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<Rights>
pub const fn from_bits(bits: u32) -> Option<Rights>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> Rights
pub const fn from_bits_truncate(bits: u32) -> Rights
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> Rights
pub const fn from_bits_retain(bits: u32) -> Rights
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<Rights>
pub fn from_name(name: &str) -> Option<Rights>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: Rights) -> bool
pub const fn intersects(&self, other: Rights) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: Rights) -> bool
pub const fn contains(&self, other: Rights) -> bool
Whether all set bits in other are also set in self.
pub fn remove(&mut self, other: Rights)
pub fn remove(&mut self, other: Rights)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn set(&mut self, other: Rights, value: bool)
pub fn set(&mut self, other: Rights, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: Rights) -> Rights
pub const fn intersection(self, other: Rights) -> Rights
The bitwise and (&) of the bits in self and other.
pub const fn difference(self, other: Rights) -> Rights
pub const fn difference(self, other: Rights) -> Rights
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: Rights) -> Rights
pub const fn symmetric_difference(self, other: Rights) -> Rights
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> Rights
pub const fn complement(self) -> Rights
The bitwise negation (!) of the bits in self, truncating the result.
impl Rights
impl Rights
pub const fn iter(&self) -> Iter<Rights> ⓘ
pub const fn iter(&self) -> Iter<Rights> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<Rights> ⓘ
pub const fn iter_names(&self) -> IterNames<Rights> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.