Struct Unowned
pub struct Unowned<'a, T> { /* private fields */ }Expand description
A borrowed value of type T.
This is primarily used for working with borrowed values of handle wrapper types.
Implementations
impl<'a, T> Unowned<'a, T>where
T: Into<NullableHandle>,
impl<'a, T> Unowned<'a, T>where
T: Into<NullableHandle>,
impl<'a, T> Unowned<'a, T>
impl<'a, T> Unowned<'a, T>
pub unsafe fn from_raw_handle(handle: u32) -> Unowned<'a, T>
pub unsafe fn from_raw_handle(handle: u32) -> Unowned<'a, T>
Create a HandleRef from a raw handle. Use this method when you are given a raw handle but
should not take ownership of it. Examples include process-global handles like the root
VMAR. This method should be called with an explicitly provided lifetime that must not
outlive the lifetime during which the handle is owned by the current process. It is unsafe
because most of the time, it is better to use a Handle to prevent leaking resources.
Safety
handle must be a valid handle (i.e. not dangling), or
ZX_HANDLE_INVALID. If handle is a valid handle, then it must not be
closed for the lifetime 'a.
pub fn raw_handle(&self) -> u32
pub fn raw_handle(&self) -> u32
Returns the raw handle’s integer value.
impl<'a> Unowned<'a, NullableHandle>
impl<'a> Unowned<'a, NullableHandle>