DispatchServiceHandler

Trait DispatchServiceHandler 

pub trait DispatchServiceHandler<H, T> {
    // Required method
    fn on_connection(handler: &H, member: &str, server_end: T);
}
A service which dispatches incoming connections to a handler.

Required Methods

fn on_connection(handler: &H, member: &str, server_end: T)

Handles a received connection request with the given handler.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors