pub trait FromWireOption<W>: Sized {
// Required method
fn from_wire_option(wire: W) -> Option<Self>;
}Expand description
An optional type which is convertible from an owned value.
Required Methods
Sourcefn from_wire_option(wire: W) -> Option<Self>
fn from_wire_option(wire: W) -> Option<Self>
Converts the given owned value to an option of this type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".