HasServiceRequest

Trait HasServiceRequest 

pub trait HasServiceRequest<T> { }
A trait indicating that a service has members of the given type.

Services are currently limited to only having protocol members with a single type, so only one instance of this trait will be implemented for each service.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors