Respond

Trait Respond 

pub trait Respond<R> {
    type Output;

    // Required method
    fn respond(response: R) -> Self::Output;
}
A method which can be responded to with a single value.

For methods which return a result, this method implicitly returns Ok of the given response.

Required Associated Types

type Output

The returned response type.

Required Methods

fn respond(response: R) -> Self::Output

Makes a response from the given input.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors