RunsTransport

Trait RunsTransport 

pub trait RunsTransport<T>
where T: ?Sized,
{ }
Identifies an executor as being able to run a transport.

Implementing RunsTransport is optional and only enables some more convenient spawning APIs.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl RunsTransport<Channel> for FuchsiaAsync

Available on crate feature fasync only.
Source

impl<E> RunsTransport<Mpsc> for E

Source

impl<E> RunsTransport<Mpsc> for E
where E: RunsTransport<Mpsc>,