Unit

Enum Unit 

#[repr(u8)]
pub enum Unit { Unit = 0, }
The empty FIDL “unit” struct.

FIDL wire type layouts follow the same rules as C/C++ type layout rules. Because every object must have a unique address, the empty “unit” type must be be a single byte that is set to zero.

Variants



Unit = 0

Empty structs are represented as a single 0u8.