Struct Instant
pub struct Instant<T, U = NsUnit>(/* private fields */);Expand description
A timestamp from the kernel. Generic over both the timeline and the units it is measured in.
Implementations
impl Instant<MonotonicTimeline>
impl Instant<MonotonicTimeline>
pub fn get() -> Instant<MonotonicTimeline>
pub fn get() -> Instant<MonotonicTimeline>
Get the current monotonic time which does not advance during system suspend.
Wraps the zx_clock_get_monotonic syscall.
pub fn after(
duration: Duration<MonotonicTimeline>,
) -> Instant<MonotonicTimeline>
pub fn after( duration: Duration<MonotonicTimeline>, ) -> Instant<MonotonicTimeline>
Compute a deadline for the time in the future that is the given Duration away.
Wraps the zx_deadline_after syscall.
pub fn sleep(self)
pub fn sleep(self)
Sleep until the given time.
Wraps the zx_nanosleep syscall.
impl Instant<BootTimeline>
impl Instant<BootTimeline>
pub fn get() -> Instant<BootTimeline>
pub fn get() -> Instant<BootTimeline>
Get the current boot time which advances during system suspend.
pub fn after(duration: Duration<BootTimeline>) -> Instant<BootTimeline>
pub fn after(duration: Duration<BootTimeline>) -> Instant<BootTimeline>
Compute a deadline for the time in the future that is the given Duration away.
impl<T> Instant<T>where
T: Timeline,
impl<T> Instant<T>where
T: Timeline,
pub const INFINITE: Instant<T>
pub const INFINITE_PAST: Instant<T>
pub const fn into_nanos(self) -> i64
pub const fn into_nanos(self) -> i64
Returns the number of nanoseconds since the epoch contained by this Time.
pub const fn from_nanos(nanos: i64) -> Instant<T>
pub const fn from_nanos(nanos: i64) -> Instant<T>
Return a strongly-typed Time from a raw number of nanoseconds.
impl Instant<MonotonicTimeline, TicksUnit>
impl Instant<MonotonicTimeline, TicksUnit>
pub fn get() -> Instant<MonotonicTimeline, TicksUnit>
pub fn get() -> Instant<MonotonicTimeline, TicksUnit>
Read the number of high-precision timer ticks on the monotonic timeline. These ticks may be processor cycles, high speed timer, profiling timer, etc. They do not advance while the system is suspended.
Wraps the zx_ticks_get syscall.
impl Instant<BootTimeline, TicksUnit>
impl Instant<BootTimeline, TicksUnit>
pub fn get() -> Instant<BootTimeline, TicksUnit>
pub fn get() -> Instant<BootTimeline, TicksUnit>
Read the number of high-precision timer ticks on the boot timeline. These ticks may be processor cycles, high speed timer, profiling timer, etc. They advance while the system is suspended.